/*
   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: GPL-2.0-or-later
*/

#ifndef GRAVATARCONFIGURESETTINGSPLUGINDIALOGTEST_H
#define GRAVATARCONFIGURESETTINGSPLUGINDIALOGTEST_H

#include <QObject>

class GravatarConfigureSettingsPluginDialogTest : public QObject
{
    Q_OBJECT
public:
    explicit GravatarConfigureSettingsPluginDialogTest(QObject *parent = nullptr);
    ~GravatarConfigureSettingsPluginDialogTest() override = default;
};

#endif // GRAVATARCONFIGURESETTINGSPLUGINDIALOGTEST_H
